#[repr(u8)]pub enum NetworkRecoveryReason {
Unspecified = 0,
Auth = 1,
Visibility = 2,
}Variants
Unspecified = 0
Unspecified / unknown reason of network failure
Auth = 1
Credentials for the configured operational network are not valid
Visibility = 2
Configured network cannot be found (e.g. the device cannot see the configured Wi-Fi SSID, Thread end-node is unable to find a parent router on the PAN)
Implementations